@@ -7,6 +7,18 @@ class DjangoldpConfig(AppConfig):
     def ready(self):
         self.auto_register_model_admin()
         self.start_activity_queue()
+        
+        # Patch guardian core to avoid prefetching permissions several times
+        from guardian.core import ObjectPermissionChecker
+        ObjectPermissionChecker._prefetch_cache_orig = ObjectPermissionChecker._prefetch_cache
+
+        def _prefetch_cache(self):
+            if hasattr(self.user, "_guardian_perms_cache"):
+                self._obj_perms_cache = self.user._guardian_perms_cache
+                return
+            self._prefetch_cache_orig()
+
+        ObjectPermissionChecker._prefetch_cache = _prefetch_cache
 
     def start_activity_queue(self):
         from djangoldp.activities.services import ActivityQueueService
@@ -22,7 +34,7 @@ class DjangoldpConfig(AppConfig):
         from django.conf import settings
         from django.contrib import admin
         from djangoldp.admin import DjangoLDPAdmin
-        from djangoldp.urls import get_all_non_abstract_subclasses_dict
+        from djangoldp.urls import get_all_non_abstract_subclasses
         from djangoldp.models import Model
 
         for package in settings.DJANGOLDP_PACKAGES:
@@ -37,9 +49,6 @@ class DjangoldpConfig(AppConfig):
             except ModuleNotFoundError:
                 pass
 
-        model_classes = get_all_non_abstract_subclasses_dict(Model)
-
-        for class_name in model_classes:
-            model_class = model_classes[class_name]
-            if not admin.site.is_registered(model_class):
-                admin.site.register(model_class, DjangoLDPAdmin)
+        for model in get_all_non_abstract_subclasses(Model):
+            if not admin.site.is_registered(model):
+                admin.site.register(model, DjangoLDPAdmin)
