@@ -128,7 +128,10 @@ MIDDLEWARE = [
 ##################
 REST_FRAMEWORK = {
     'DEFAULT_SCHEMA_CLASS': 'drf_spectacular.openapi.AutoSchema',
-    'DEFAULT_PAGINATION_CLASS': 'djangoldp.pagination.LDPPagination'
+    'DEFAULT_PAGINATION_CLASS': 'djangoldp.pagination.LDPPagination',
+    'DEFAULT_RENDERER_CLASSES': [
+        'rest_framework.renderers.JSONRenderer',
+    ]
 }
 
 ###################
