@@ -211,9 +211,19 @@ class Model(models.Model):
         if type == 'foaf:user':
             return get_user_model()
 
+        def find_subclass_with_rdf_type(cls):
+            if getattr(cls._meta, "rdf_type", None) == type:
+                return cls
+            for subcls in cls.__subclasses__():
+                result = find_subclass_with_rdf_type(subcls)
+                if result:
+                    return result
+            return None
+
         for subcls in Model.__subclasses__():
-            if getattr(subcls._meta, "rdf_type", None) == type:
-                return subcls
+            result = find_subclass_with_rdf_type(subcls)
+            if result:
+                return result
 
         return None
 
@@ -267,6 +277,7 @@ class Activity(Model):
     class Meta(Model.Meta):
         container_path = "activities"
         rdf_type = 'as:Activity'
+        disable_url = True
 
     def to_activitystream(self):
         return json.loads(self.payload)
@@ -284,6 +295,9 @@ class ScheduledActivity(Activity):
         self.is_finished = False
         super(ScheduledActivity, self).save(*args, **kwargs)
 
+    class Meta(Model.Meta):
+        disable_url = True
+
 
 class Follower(Model):
     '''Models a subscription on a model. When the model is saved, an Update activity will be sent to the inbox'''
@@ -294,6 +308,9 @@ class Follower(Model):
     def __str__(self):
         return 'Inbox ' + str(self.inbox) + ' on ' + str(self.object)
 
+    class Meta(Model.Meta):
+        disable_url = True
+
 class DynamicNestedField:
     '''
     Used to define a method as a nested_field.
@@ -333,7 +350,7 @@ def auto_urlid(sender, instance, **kwargs):
 def create_role_groups(sender, instance, created, **kwargs):
     if created:
         for name, params in getattr(instance._meta, 'permission_roles', {}).items():
-            group = Group.objects.create(name=f'LDP_{instance._meta.model_name}_{name}_{instance.id}')
+            group, x = Group.objects.get_or_create(name=f'LDP_{instance._meta.model_name}_{name}_{instance.id}')
             setattr(instance, name, group)
             instance.save()
             if params.get('add_author'):
