@@ -1,21 +1,23 @@
 from django.conf import settings
-from django.contrib.auth.models import AbstractUser
+from django.contrib.auth.models import AbstractUser, Group
 from django.db import models
 from django.utils.datetime_safe import date
 
-from djangoldp.models import Model
-from djangoldp.permissions import LDPPermissions, SuperUserPermission
+from djangoldp.models import Model, DynamicNestedField
+from djangoldp.permissions import ACLPermissions, AuthenticatedOnly, ReadOnly, \
+    ReadAndCreate, AnonymousReadOnly, OwnerPermissions, InheritPermissions
+
+from .permissions import Only2WordsForToto, ReadOnlyStartsWithA
 
 
 class User(AbstractUser, Model):
-
     class Meta(AbstractUser.Meta, Model.Meta):
+        ordering = ['pk']
         serializer_fields = ['@id', 'username', 'first_name', 'last_name', 'email', 'userprofile',
-                             'conversation_set', 'circle_set', 'projects']
-        anonymous_perms = ['view', 'add']
-        authenticated_perms = ['inherit', 'change']
-        owner_perms = ['inherit']
+                             'conversation_set','groups', 'projects', 'owned_circles']
+        permission_classes = [ReadAndCreate|OwnerPermissions]
         rdf_type = 'foaf:user'
+        nested_fields = ['owned_circles']
 
 
 class Skill(Model):
@@ -28,10 +30,10 @@ class Skill(Model):
         return self.joboffer_set.filter(date__gte=date.today())
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add', 'change']
-        owner_perms = ['inherit', 'delete', 'control']
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
         serializer_fields = ["@id", "title", "recent_jobs", "slug", "obligatoire"]
+        nested_fields = ['joboffer_set']
         lookup_field = 'slug'
         rdf_type = 'hd:skill'
 
@@ -49,14 +51,16 @@ class JobOffer(Model):
         return self.skills.all().first()
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'change', 'add']
-        owner_perms = ['inherit', 'delete', 'control']
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly, ReadOnly|OwnerPermissions]
         serializer_fields = ["@id", "title", "skills", "recent_skills", "resources", "slug", "some_skill", "urlid"]
+        nested_fields = ['skills', 'resources', 'recent_skills']
         container_path = "job-offers/"
         lookup_field = 'slug'
         rdf_type = 'hd:joboffer'
 
+JobOffer.recent_skills.field = DynamicNestedField(Skill, 'recent_skills')
+
 
 class Conversation(models.Model):
     description = models.CharField(max_length=255, blank=True, null=True)
@@ -66,9 +70,9 @@ class Conversation(models.Model):
     observers = models.ManyToManyField(settings.AUTH_USER_MODEL, blank=True, related_name='observed_conversations')
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add']
-        owner_perms = ['inherit', 'change', 'delete', 'control']
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
+        nested_fields=["message_set", "observers"]
         owner_field = 'author_user'
 
 
@@ -77,10 +81,9 @@ class Resource(Model):
     description = models.CharField(max_length=255)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view', 'add', 'delete', 'change', 'control']
-        authenticated_perms = ['inherit']
-        owner_perms = ['inherit']
+        ordering = ['pk']
         serializer_fields = ["@id", "joboffers"]
+        nested_fields = ['joboffers']
         depth = 1
         rdf_type = 'hd:Resource'
 
@@ -92,11 +95,11 @@ class OwnedResource(Model):
                              on_delete=models.CASCADE)
 
     class Meta(Model.Meta):
-        anonymous_perms = []
-        authenticated_perms = []
-        owner_perms = ['view', 'delete', 'add', 'change', 'control']
+        ordering = ['pk']
+        permission_classes = [OwnerPermissions]
         owner_field = 'user'
         serializer_fields = ['@id', 'description', 'user']
+        nested_fields = ['owned_resources']
         depth = 1
 
 
@@ -106,26 +109,51 @@ class OwnedResourceVariant(Model):
                              on_delete=models.CASCADE)
 
     class Meta(Model.Meta):
-        anonymous_perms = []
-        authenticated_perms = ['view', 'change']
-        owner_perms = ['view', 'delete', 'add', 'change', 'control']
+        ordering = ['pk']
+        permission_classes = [ReadOnly|OwnerPermissions]
         owner_field = 'user'
         serializer_fields = ['@id', 'description', 'user']
         depth = 1
 
 
+class OwnedResourceNestedOwnership(Model):
+    description = models.CharField(max_length=255, blank=True, null=True)
+    parent = models.ForeignKey(OwnedResource, blank=True, null=True, related_name="owned_resources",
+                               on_delete=models.CASCADE)
+
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [OwnerPermissions]
+        owner_field = 'parent__user'
+        serializer_fields = ['@id', 'description', 'parent']
+        nested_fields = ['owned_resources']
+        depth = 1
+
+
+class OwnedResourceTwiceNestedOwnership(Model):
+    description = models.CharField(max_length=255, blank=True, null=True)
+    parent = models.ForeignKey(OwnedResourceNestedOwnership, blank=True, null=True, related_name="owned_resources",
+                               on_delete=models.CASCADE)
+
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [OwnerPermissions]
+        owner_field = 'parent__parent__user'
+        serializer_fields = ['@id', 'description', 'parent']
+        depth = 1
+
+
 class UserProfile(Model):
     description = models.CharField(max_length=255, blank=True, null=True)
     user = models.OneToOneField(settings.AUTH_USER_MODEL, related_name='userprofile', on_delete=models.CASCADE)
     slug = models.SlugField(blank=True, null=True, unique=True)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit']
-        owner_perms = ['inherit', 'change', 'control']
+        ordering = ['pk']
+        permission_classes = [AuthenticatedOnly,ReadOnly|OwnerPermissions]
         owner_field = 'user'
         lookup_field = 'slug'
-        serializer_fields = ['@id', 'description', 'settings', 'user', 'post_set']
+        serializer_fields = ['@id', 'description', 'settings', 'user']
         depth = 1
 
 
@@ -134,9 +162,8 @@ class NotificationSetting(Model):
     receiveMail = models.BooleanField(default=True)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view', 'change']
-        authenticated_perms = ['inherit']
-        owner_perms = ['inherit', 'change', 'control']
+        ordering = ['pk']
+        permission_classes = [ReadAndCreate|OwnerPermissions]
 
 
 class Message(models.Model):
@@ -145,9 +172,8 @@ class Message(models.Model):
     author_user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.DO_NOTHING)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add']
-        owner_perms = ['inherit', 'change', 'delete', 'control']
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
 
 
 class Dummy(models.Model):
@@ -155,80 +181,148 @@ class Dummy(models.Model):
     slug = models.SlugField(blank=True, null=True, unique=True)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add']
-        owner_perms = ['inherit', 'change', 'delete', 'control']
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
 
 
 class LDPDummy(Model):
     some = models.CharField(max_length=255, blank=True, null=True)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add']
-        owner_perms = ['inherit', 'change', 'delete', 'control']
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
+        nested_fields = ['anons']
 
 
-# model used in django-guardian permission tests (no anonymous etc permissions set)
+# model used in django-guardian permission tests (no permission to anyone except suuperusers)
 class PermissionlessDummy(Model):
     some = models.CharField(max_length=255, blank=True, null=True)
     slug = models.SlugField(blank=True, null=True, unique=True)
     parent = models.ForeignKey(LDPDummy, on_delete=models.DO_NOTHING, related_name="anons", blank=True, null=True)
 
     class Meta(Model.Meta):
-        anonymous_perms = []
-        authenticated_perms = []
-        owner_perms = []
-        permissions = (
-            ('custom_permission_permissionlessdummy', 'Custom Permission'),
-        )
+        ordering = ['pk']
+        permission_classes = [ACLPermissions]
+        lookup_field='slug'
+        permissions = (('custom_permission_permissionlessdummy', 'Custom Permission'),)
 
 
 class Post(Model):
     content = models.CharField(max_length=255)
-    author = models.ForeignKey(UserProfile, blank=True, null=True, on_delete=models.SET_NULL)
+    author = models.ForeignKey(User, blank=True, null=True, on_delete=models.SET_NULL)
     peer_user = models.ForeignKey(settings.AUTH_USER_MODEL, blank=True, null=True, related_name="peers_post",
                                   on_delete=models.SET_NULL)
 
     class Meta(Model.Meta):
+        ordering = ['pk']
         auto_author = 'author'
-        auto_author_field = 'userprofile'
-        anonymous_perms = ['view', 'add', 'delete', 'add', 'change', 'control']
-        authenticated_perms = ['inherit']
-        owner_perms = ['inherit']
         rdf_type = 'hd:post'
 
+class AnonymousReadOnlyPost(Model):
+    content = models.CharField(max_length=255)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [AnonymousReadOnly]
+class AuthenticatedOnlyPost(Model):
+    content = models.CharField(max_length=255)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [AuthenticatedOnly]
+class ReadOnlyPost(Model):
+    content = models.CharField(max_length=255)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [ReadOnly]
+class ReadAndCreatePost(Model):
+    content = models.CharField(max_length=255)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [ReadAndCreate]
+
+class ANDPermissionsDummy(Model):
+    title = models.CharField(max_length=255)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [ReadOnlyStartsWithA&Only2WordsForToto]
+class ORPermissionsDummy(Model):
+    title = models.CharField(max_length=255)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [ReadOnlyStartsWithA|Only2WordsForToto]
+
 
 class Invoice(Model):
     title = models.CharField(max_length=255, blank=True, null=True)
     date = models.DateField(blank=True, null=True)
 
     class Meta(Model.Meta):
+        ordering = ['pk']
         depth = 2
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add', 'change']
-        owner_perms = ['inherit', 'delete', 'control']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
+        nested_fields = ['batches']
 
 
 class Circle(Model):
     name = models.CharField(max_length=255, blank=True)
     description = models.CharField(max_length=255, blank=True)
-    team = models.ManyToManyField(settings.AUTH_USER_MODEL, through="CircleMember", blank=True)
     owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_circles", on_delete=models.DO_NOTHING, null=True, blank=True)
+    members = models.OneToOneField(Group, related_name="circle", on_delete=models.SET_NULL, null=True, blank=True)
+    admins = models.OneToOneField(Group, related_name="admin_circle", on_delete=models.SET_NULL, null=True, blank=True)
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view', 'add', 'delete', 'add', 'change', 'control']
-        authenticated_perms = ["inherit"]
-        serializer_fields = ['@id', 'name', 'description', 'members', 'team', 'owner', 'space']
+        ordering = ['pk']
+        auto_author = 'owner'
+        depth = 1
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions|ACLPermissions]
+        permission_roles = {
+            'members': {'perms': ['view'], 'add_author': True},
+            'admins': {'perms': ['view', 'change', 'control'], 'add_author': True},
+        }
+        serializer_fields = ['@id', 'name', 'description', 'members', 'owner', 'space']
         rdf_type = 'hd:circle'
 
+Group._meta.inherit_permissions += ['circle','admin_circle']
+Group._meta.serializer_fields += ['circle', 'admin_circle']
+
+class RestrictedCircle(Model):
+    name = models.CharField(max_length=255, blank=True)
+    description = models.CharField(max_length=255, blank=True)
+    owner = models.ForeignKey(settings.AUTH_USER_MODEL, related_name="owned_restrictedcircles", on_delete=models.DO_NOTHING, null=True, blank=True)
+    members = models.ForeignKey(Group, related_name="restrictedcircles", on_delete=models.SET_NULL, null=True, blank=True)
+    admins = models.ForeignKey(Group, related_name="admin_restrictedcircles", on_delete=models.SET_NULL, null=True, blank=True)
+
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        auto_author = 'owner'
+        permission_classes = [ACLPermissions]
+        permission_roles = {
+            'members': {'perms': ['view'], 'add_author': True},
+            'admins': {'perms': ['view', 'change', 'control'], 'add_author': True},
+        }
+        rdf_type = 'hd:circle'
+class RestrictedResource(Model):
+    content = models.CharField(max_length=255, blank=True)
+    circle = models.ForeignKey(RestrictedCircle, on_delete=models.CASCADE)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [InheritPermissions]
+        inherit_permissions = ['circle']
+
+class DoubleInheritModel(Model):
+    content = models.CharField(max_length=255, blank=True)
+    ro_ancestor = models.ForeignKey(ReadOnlyPost, on_delete=models.CASCADE, null=True, blank=True)
+    circle = models.ForeignKey(RestrictedCircle, on_delete=models.CASCADE, null=True, blank=True)
+    class Meta(Model.Meta):
+        ordering = ['pk']
+        permission_classes = [InheritPermissions]
+        inherit_permissions = ['circle', 'ro_ancestor']
 
 class Space(Model):
     name = models.CharField(max_length=255, blank=True)
     circle = models.OneToOneField(to=Circle, null=True, blank=True, on_delete=models.CASCADE, related_name='space')
 
     class Meta(Model.Meta):
-        pass
+        ordering = ['pk']
 
 
 class Batch(Model):
@@ -236,41 +330,26 @@ class Batch(Model):
     title = models.CharField(max_length=255, blank=True, null=True)
 
     class Meta(Model.Meta):
+        ordering = ['pk']
         serializer_fields = ['@id', 'title', 'invoice', 'tasks']
-        anonymous_perms = ['view', 'add']
-        authenticated_perms = ['inherit', 'add']
-        owner_perms = ['inherit', 'change', 'delete', 'control']
+        permission_classes = [ReadAndCreate|OwnerPermissions]
         depth = 1
         rdf_type = 'hd:batch'
 
 
-class CircleMember(Model):
-    circle = models.ForeignKey(Circle, on_delete=models.CASCADE, related_name='members')
-    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=models.CASCADE, related_name="circles")
-    is_admin = models.BooleanField(default=False)
-
-    class Meta(Model.Meta):
-        container_path = "circle-members/"
-        anonymous_perms = ['view', 'add', 'delete', 'add', 'change', 'control']
-        authenticated_perms = ['inherit']
-        unique_together = ['user', 'circle']
-        rdf_type = 'hd:circlemember'
-
-
 class Task(models.Model):
     batch = models.ForeignKey(Batch, on_delete=models.CASCADE, related_name='tasks')
     title = models.CharField(max_length=255)
 
     class Meta(Model.Meta):
+        ordering = ['pk']
         serializer_fields = ['@id', 'title', 'batch']
-        anonymous_perms = ['view']
-        authenticated_perms = ['inherit', 'add']
-        owner_perms = ['inherit', 'change', 'delete', 'control']
+        permission_classes = [AnonymousReadOnly,ReadAndCreate|OwnerPermissions]
 
 
 class ModelTask(Model, Task):
     class Meta(Model.Meta):
-        pass
+        ordering = ['pk']
 
 STATUS_CHOICES = [
     ('Public', 'Public'),
@@ -284,9 +363,9 @@ class Project(Model):
     members = models.ManyToManyField(settings.AUTH_USER_MODEL, blank=True, related_name='projects')
 
     class Meta(Model.Meta):
-        anonymous_perms = ['view', 'add', 'delete', 'add', 'change', 'control']
-        authenticated_perms = ["inherit"]
+        ordering = ['pk']
         rdf_type = 'hd:project'
+        nested_fields = ['members']
 
 
 class DateModel(Model):
@@ -294,6 +373,7 @@ class DateModel(Model):
     value = models.DateField()
 
     class Meta(Model.Meta):
+        ordering = ['pk']
         rdf_type = "hd:date"
         serializer_fields_exclude = ['excluded']
 
@@ -302,6 +382,7 @@ class DateChild(Model):
     parent = models.ForeignKey(DateModel, on_delete=models.CASCADE, related_name='children')
 
     class Meta(Model.Meta):
+        ordering = ['pk']
         rdf_type = 'hd:datechild'
 
 
@@ -309,21 +390,13 @@ class MyAbstractModel(Model):
     defaultsomething = models.CharField(max_length=255, blank=True)
 
     class Meta(Model.Meta):
-        permission_classes = [LDPPermissions]
+        ordering = ['pk']
+        permission_classes = [ACLPermissions]
         abstract = True
         rdf_type = "wow:defaultrdftype"
 
 
 class NoSuperUsersAllowedModel(Model):
     class Meta(Model.Meta):
-        anonymous_perms = []
-        authenticated_perms = []
-        owner_perms = []
-        superuser_perms = []
-        permission_classes = [LDPPermissions]
-
-
-class ComplexPermissionClassesModel(Model):
-    class Meta(Model.Meta):
-        permission_classes = [LDPPermissions, SuperUserPermission]
-        superuser_perms = []
+        ordering = ['pk']
+        permission_classes = [ACLPermissions]
\ No newline at end of file
