@@ -1,4 +1,4 @@
-from rest_framework.test import APIRequestFactory, APIClient, APITestCase
+from rest_framework.test import APIClient, APIRequestFactory, APITestCase
 
 from djangoldp.tests.models import Post
 
@@ -18,11 +18,11 @@ class TestPagination(APITestCase):
         response = self.client.get('/posts/', content_type='application/ld+json')
         self.assertEqual(response.status_code, 200)
         self.assertIn('link', response.headers)
-        self.assertEquals(response.headers['link'], '<http://testserver/posts/?p=2>; rel="next"')
+        self.assertEqual(response.headers['link'], '<http://testserver/posts/?p=2>; rel="next"')
 
     def test_previous(self):
         response = self.client.get('/posts/?p=2', content_type='application/ld+json')
         self.assertEqual(response.status_code, 200)
         self.assertIn('link', response.headers)
-        self.assertEquals(response.headers['link'],
+        self.assertEqual(response.headers['link'],
                           '<http://testserver/posts/>; rel="prev", <http://testserver/posts/?p=3>; rel="next"')
