@@ -2,8 +2,7 @@ from hashlib import md5
 
 from Cryptodome.PublicKey import RSA
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
-
+from django.utils.translation import gettext_lazy as _
 
 class RSAKey(models.Model):
 
